@@ -106,9 +106,14 @@ qx.Class.define("callbackery.ui.plugin.Form", {
                 var callback = function(e){
                     var data = e.getData();
                     // handle events from selectboxes
-                     if (control.getSelection){
-                         data = data[0].getModel();
-                     }
+                    if (control.getSelection && qx.lang.Type.isArray(data)){
+                        if (data.length > 0 && data[0]['getModel']){
+                            data = data[0].getModel();
+                        }
+                        else {
+                            data = null;
+                        }
+                    }
                     var required = control.getRequired();
                     if (required){
                         if (data == null || data == '' ){
